# ErisPulse-Weather
这是一个基于ErisPulse开发的天气查询插件，支持今日查询、五日查询、城市绑定等多种功能。  
目前城市绑定管理的数据记录在ErisPulse的EnvManager的SQLite数据库中，您可以使用`env.get("Weather:{用户ID}", "默认值")`来获取绑定数据
## 使用
~~~bash
pip install ErisPulse-Weather
~~~
安装完成后，可以使用`/天气`或`天气`指令来调用本模块。  

## 指令
每条指令都需要以`/天气`或`天气`为消息前缀，如`/天气 今日 桂林`
| 名称 | 作用 |
| :---: | :---: |
| /天气 今日 [城市名称] | 获取今日该城市的天气 |
| /天气 五日 [城市名称] | 获取将来五天该城市的天气 |
| /天气 绑定 <城市名称> | 绑定城市，如果绑定则前二指令可以不传城市名称，如需更改请直接再次调用 |
| /天气 解绑 | 解绑当前绑定的城市 | 
| /天气 查绑 | 查询当前绑定的城市 |
实际上，指令与参数间的空格并不是必须的。您可以省略该空格，但我们推荐使用带空格调用的方式。
## 功能
目前支持以下功能：  
- [x] 今日天气查询
- [x] 五日天气查询
- [x] 城市绑定管理
接下来可能会支持的功能：  
- [ ] 自定义平台获取
- [ ] 配置哪些内容不展示
- [ ] 使用MarkDown发送

> **有关Markdown的一些信息**：  
> 1.仅可用于支持Markdown消息的平台，如果不支持则直接发送文本  
> 2.[什么是Markdown？点我了解](https://markdown.com.cn/intro.html)